#[repr(u8)]pub enum NuwS2 {
NUW_S2_0 = 0,
NUW_S2_1 = 1,
}Variants
NUW_S2_0 = 0
The non-secure user write access is disabled for the second slave.
NUW_S2_1 = 1
The non-secure user write access is enabled for the second slave.
Implementations