#[repr(u8)]pub enum SsrS1 {
SSR_S1_0 = 0,
SSR_S1_1 = 1,
}Variants
SSR_S1_0 = 0
The secure supervisor read access is disabled for the first slave.
SSR_S1_1 = 1
The secure supervisor read access is enabled for the first slave.
Implementations