#[repr(u8)]pub enum SswS1 {
SSW_S1_0 = 0,
SSW_S1_1 = 1,
}Variants
SSW_S1_0 = 0
The secure supervisor write access is disabled for the first slave.
SSW_S1_1 = 1
The secure supervisor write access is enabled for the first slave.
Implementations