#[repr(u8)]pub enum SuwS1 {
SUW_S1_0 = 0,
SUW_S1_1 = 1,
}Variants
SUW_S1_0 = 0
The secure user write access is disabled for the first slave.
SUW_S1_1 = 1
The secure user write access is enabled for the first slave.
Implementations