#[repr(u8)]pub enum SuwS2 {
SUW_S2_0 = 0,
SUW_S2_1 = 1,
}Variants
SUW_S2_0 = 0
The secure user write access is disabled for the second slave.
SUW_S2_1 = 1
The secure user write access is enabled for the second slave.
Implementations